@@ -1,11 +1,7 @@
 import argparse
 
-from .api import py2pyz, create_archive, create_shell_script, poetry2pyz, pip2pyz
-
-
-def main_py2pyz(args: argparse.Namespace):
-    output = py2pyz(**vars(args))
-    print(f'Created {str(output)}')
+from .api import py2pyz, create_archive_zau, create_shell_script, poetry2pyz, pip2pyz
+from .config import DEFAULT_ZIPAPP_FILTER
 
 
 def main_create_archive(args: argparse.Namespace):
@@ -19,20 +15,27 @@ def main_create_archive(args: argparse.Namespace):
         print("Interpreter: {}".format(interpreter or "<none>"))
         sys.exit(0)
 
-    output = create_archive(**vars(args))
+    output = create_archive_zau(**vars(args), filter=DEFAULT_ZIPAPP_FILTER)
+    print(f'Created {str(output)}')
+
+
+def main_py2pyz(args: argparse.Namespace):
+    if hasattr(args, 'requirement'):
+        args.use_requirements_txt = True
+    output = py2pyz(**vars(args), filter=DEFAULT_ZIPAPP_FILTER)
     print(f'Created {str(output)}')
 
 
 def main_create_shell_script(args: argparse.Namespace):
-    output = create_shell_script(**vars(args))
+    output = create_shell_script(**vars(args), filter=DEFAULT_ZIPAPP_FILTER)
     print(f'Created {str(output)}')
 
 
 def main_poetry2pyz(args: argparse.Namespace):
-    output = poetry2pyz(**vars(args))
+    output = poetry2pyz(**vars(args), filter=DEFAULT_ZIPAPP_FILTER)
     print(f'Created {str(output)}')
 
 
 def main_pip2pyz(args: argparse.Namespace):
-    output = pip2pyz(**vars(args))
+    output = pip2pyz(**vars(args), filter=DEFAULT_ZIPAPP_FILTER)
     print(f'Created {str(output)}')
